@@ -8,7 +8,7 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 __all__ = ['generate_ai_plugins_classes']
 
-IF_PLUGINS = ['ADF062021', 'GBA032023', 'AEM072022', 'ASF012023', 'DBX032022', 'SOP072023', 'GDR052023', 'ZRM082023', 'ODS052024', 'TDO042024', 'ABY122023', 'ASM0220223', 'AHD062022', 'ANS032024', 'ATR122022', 'TAB072023', 'ADB112022', 'KBN062023', 'AEC082022', 'MFL022023', 'TER102023', 'QLC092022', 'RST062023', 'ZFN032022', 'GDQ112023', 'ABK042023', 'GDP042022', 'JEN022024', 'SFI122022', 'GDU102023', 'GVM062022', 'ZML022023', 'ABA092022', 'GDF032022', 'GBQ102022', 'ZVM062022', 'DBT042023', 'ADY122023', 'ZDX112021', 'AAR072022', 'ADP122022', 'BOO032022', 'ZLA112022', 'MFW022023', 'ALM012024', 'GCC052024', 'OVM012024', 'ODI032024', 'UIP072021', 'GFU012023', 'ICS032022', 'GWF092023', 'GDM082023', 'ODF0420241', 'NFI042024', 'CMR022024', 'ACF082023', 'COM032023', 'BAK092023', 'AQS012023', 'ACS042023', 'ZBA042022', 'SNF092022', 'GLU062021', 'AMM082023', 'AAT052023', 'ZSY062022', 'TDM052022', 'ASQ032024', 'MBI042022', 'ADO112023']
+IF_PLUGINS = ['ZFN032022', 'ANS032024', 'OVM012024', 'ASM0220223', 'TAB072023', 'ADY122023', 'ABY122023', 'ODF0420241', 'NFI042024', 'AQS012023', 'SFI122022', 'KBN062023', 'ADO112023', 'ABA092022', 'AMM082023', 'GCC052024', 'AEC082022', 'ASF012023', 'TDM052022', 'BOO032022', 'ICS032022', 'GBQ102022', 'ZSY062022', 'MFW022023', 'GFU012023', 'AAR072022', 'RST062023', 'ALM012024', 'ASQ032024', 'TER102023', 'ZBA042022', 'ZRM082023', 'AHD062022', 'GVM062022', 'CMR022024', 'COM032023', 'GBA032023', 'DBX032022', 'SOP072023', 'SNF092022', 'ADB112022', 'ACF082023', 'ZVM062022', 'GDM082023', 'TDO042024', 'GDU102023', 'JEN022024', 'GLU062021', 'AAT052023', 'UIP072021', 'ATR122022', 'ZML022023', 'ZLA112022', 'GDR052023', 'QLC092022', 'BAK092023', 'ACS042023', 'ABK042023', 'ODI032024', 'MBI042022', 'ADF062021', 'DBT042023', 'ODS052024', 'ADP122022', 'MFL022023', 'ZDX112021', 'GDP042022', 'GDQ112023', 'GWF092023', 'AEM072022', 'GDF032022']
 
 
 imports_str = '''from aapi import *
